

# Runes analyzer 

Elder Futhark, Younger Futhark, Short-twig Younger Futhark available
An example of transcription.

To do list:

* use spraakbanken corpus of runic inscriptions and track phonetic evolutions

Source:

* Les causes de la réduction du *futhark* germanique, les glides et le vocalisme. By Alain MAREZ.
